Struct ad4m_client::languages::ByAddress
source · pub struct ByAddress;Trait Implementations
sourceimpl GraphQLQuery for ByAddress
impl GraphQLQuery for ByAddress
type Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
type ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.