Struct ad4m_client::languages::Meta
source · pub struct Meta;Trait Implementations
sourceimpl<'de> Deserialize<'de> for Meta
impl<'de> Deserialize<'de> for Meta
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where __D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl GraphQLQuery for Meta
impl GraphQLQuery for Meta
type Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
type ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.