Struct ad4m_client::runtime::LinkLanguageTemplates
source · pub struct LinkLanguageTemplates;Trait Implementations
sourceimpl GraphQLQuery for LinkLanguageTemplates
impl GraphQLQuery for LinkLanguageTemplates
type Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
type ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.